==> nextcloud-22.2.5.tar.bz2: nextcloud/apps/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Notiek migrācija. Lūdzu, pagaidiet, līdz migrēšana ir pabeigta",
    "Migration started …" : "Uzsākta migrācija...",
    "Saved" : "Saglabāts",
    "Not saved" : "Nav saglabāts",
    "Sending…" : "Sūta …",
    "Email sent" : "Vēstule nosūtīta",
    "Private" : "Privāts",
    "Local" : "Lokāls",
    "Verify" : "Verificēt",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Select a profile picture" : "Izvēlieties profila attēlu",
    "Groups" : "Grupas",
    "Group list is empty" : "Grupu saraksts ir tukšš",
    "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
    "You successfully logged in using two-factor authentication (%1$s)" : "Esat veiksmīgi pieteicies, izmantojot divpakāpju autentifikācija (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pieteikšanās mēģinājums, izmantojot divpakāpju autentifikāciju neizdevās (%1$s)",
    "Couldn't remove app." : "Nebija iespējams noņemt lietotni.",
    "Couldn't update app." : "Nevarēja atjaunināt lietotni.",
    "Wrong password" : "Nepareiza parole",
    "No user supplied" : "Nav norādīts lietotājs",
    "Authentication error" : "Autentifikācijas kļūda",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Radās kļūda, nosūtot e-pastu. Lūdzu, pārskatiet savus iestatījumus. (Kļūda: %s)",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "Settings saved" : "Iestatījumi saglabāti",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "Unable to change email address" : "Nevar mainīt e-pasta adresi",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Apps" : "Lietotnes",
    "Settings" : "Iestatījumi",
    "Personal" : "Personīgs",
    "Additional settings" : "Papildu iestatījumi",
    "Sharing" : "Koplietošana",
    "Personal info" : "Personiskā informācija",
    "Email server" : "E-pasta serveris",
    "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
    "Create" : "Izveidot",
    "Change" : "Mainīt",
    "Delete" : "Dzēst",
    "Unlimited" : "Neierobežota",
    "None" : "Nav",
    "Limit to groups" : "Grupu ierobežojums",
    "Save changes" : "Saglabāt izmaiņas",
    "All" : "Visi",
    "No results" : "Nav rezultātu",
    "Update to {version}" : "Atjaunināts uz {version}",
    "Remove" : "Izņemt",
    "Disable" : "Deaktivēt",
    "Visit website" : "Apmeklējiet vietni",
    "Report a bug" : "Ziņot par kļūdu",
    "User documentation" : "Lietotāja dokumentācija",
    "Admin documentation" : "Administratora dokumentācija",
    "Developer documentation" : "Izstrādātāja dokumentācija",
    "No apps found for your version" : "Neatrada lietotnes jūsu versijai",
    "Rename" : "Pārsaukt",
    "Revoke" : "Atsaukt",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "iPhone" : "iPhone",
    "Sync client - {os}" : "Sync klients - {os}",
    "This session" : "Šajā sesijā",
    "Device" : "Ierīce",
    "Last activity" : "Pēdējās darbības",
    "App name" : "Lietotnes nosaukums",
    "Create new app password" : "Izveidot jaunu lietotnes paroli",
    "Use the credentials below to configure your app or device." : "Izmantot akreditācijas datus, lai konfigurētu savu lietotni vai ierīci.",
    "For security reasons this password will only be shown once." : "Drošības apsvērumu dēļ šī parole, tiks parādīta tikai vienreiz.",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Done" : "Pabeigts",
    "Copied!" : "Nokopēts!",
    "Copy" : "Kopēt",
    "Your email address" : "Jūsu e-pasta adrese",
    "No email address set" : "Nav norādīts e-pasts",
    "Language" : "Valoda",
    "Help translate" : "Palīdzi tulkot",
    "Add" : "Pievienot",
    "Cancel" : "Atcelt",
    "Display name" : "Ekrāna vārds",
    "Email" : "E-pasts",
    "Group admin for" : "Admin grupa",
    "Quota" : "Apjoms",
    "Storage location" : "Krātuves atrašanās vieta",
    "Last login" : "Pēdējā pieteikšanās",
    "Default quota" : "Apjoms pēc noklusējuma",
    "Updates" : "Atjauninājumi",
    "Details" : "Detaļas",
    "Add group" : "Pievienot grupu",
    "Admins" : "Admins",
    "Send email to new user" : "Sūtīt e-pastu jaunajam lietotājam",
    "Address" : "Adrese",
    "Full name" : "Pilns vārds",
    "Phone number" : "Tālruņa numurs",
    "Twitter" : "Twitter",
    "Website" : "Mājaslapa",
    "Enable" : "Aktivēt",
    "Never" : "Nekad",
    "App update" : "Programmu atjaunināšana",
    "Administrator documentation" : "Administratora dokumentācija",
    "Documentation" : "Dokumentācija",
    "Forum" : "Forums",
    "Login" : "Autorizēties",
    "Plain" : "vienkāršs teksts",
    "NT LAN Manager" : "NT LAN Pārvaldnieks",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Atvērt dokumentāciju",
    "Send mode" : "Sūtīšanas metode",
    "Encryption" : "Šifrēšana",
    "From address" : "No adreses",
    "Authentication method" : "Autentifikācijas metode",
    "Authentication required" : "Nepieciešama autentifikācija",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Credentials" : "Akreditācijas dati",
    "SMTP Username" : "SMTP lietotājvārds",
    "SMTP Password" : "SMTP parole",
    "Save" : "Saglabāt",
    "Send email" : "Sūtīt e-pastu",
    "All checks passed." : "Visas pārbaudes veiksmīgas.",
    "Version" : "Versija",
    "Server-side encryption" : "Servera šifrēšana",
    "Enable server-side encryption" : "Ieslēgt servera šifrēšanu",
    "Please read carefully before activating server-side encryption: " : "Lūdzu, izlasiet uzmanīgi pirms aktivējiet servera šifrēšanu:",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrēšana vien negarantē sistēmas drošību. Skatiet dokumentāciju, lai iegūtu papildinformāciju par šifrēšanas lietotnes izmantošanu un atbalstītajiem izmantošanas veidiem.",
    "Be aware that encryption always increases the file size." : "Jāapzinās, ka šifrēšanas vienmēr palielina datnes lielumu.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Vienmēr ir ieteicams regulāri veidot dublējumkopijas datu šifrēšanas gadījumam, pārliecinieties, lai dublētu, šifrēšanas atslēgas ir kopā ar jūsu datiem.",
    "This is the final warning: Do you really want to enable encryption?" : "Šis ir pēdējais brīdinājums: vai tiešām vēlaties iespējot šifrēšanu?",
    "Enable encryption" : "Ieslēgt šifrēšanu",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nav ielādēts šifrēšanas moduļis, lūdzu, aktivizējiet šifrēšanas moduli lietotņu izvēlnē.",
    "Select default encryption module:" : "Atlasiet noklusēto šifrēšanas moduli:",
    "Start migration" : "Sākt migrāciju",
    "Allow apps to use the Share API" : "Ļaut programmām izmantot koplietošanas API",
    "Enforce expiration date" : "Uzspiest beigu termiņu",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Enforce password protection" : "Ieviest paroles aizsardzību",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Allow sharing with groups" : "Atļaut koplietošanu ar grupām",
    "Restrict users to only share with users in their groups" : "Ierobežot lietotājiem koplietot tikai ar lietotājiem savās grupās",
    "Exclude groups from sharing" : "Izslēgt grupas no koplietošanas",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Izstrādātās {communityopen}Nextcloud kopiena {linkclose},  {githubopen} avota kods {linkclose} licencēts saskaņā ar {licenseopen}AGPL{linkclose}.",
    "Profile picture" : "Profila attēls",
    "Upload new" : "Ielādēt jaunu",
    "Select from Files" : "Izvēlēties no Datnes",
    "Remove image" : "Novākt attēlu",
    "png or jpg, max. 20 MB" : "png vai jpg, max. 20 MB",
    "Choose as profile picture" : "Izvēlēties kā profila attēlu",
    "Your phone number" : "Jūsu tālruņa numurs",
    "Your postal address" : "Jūsu pasta adrese",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "Public" : "Publisks",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "lietotņu instalēšana un atjaunināšana, izmantojot lietotņu veikalu vai Federatīvo Cloud koplietošanu",
    "You need to set your user email before being able to send test emails." : "Nepieciešams norādīt sava lietotāja e-pasta adresi, lai nosūtīta testa e-pastus.",
    "Close" : "Aizvērt",
    "All languages" : "Visas valodas",
    "Everyone" : "Visi",
    "mail" : "e-pasts",
    "Test email settings" : "Izmēģināt e-pasta iestatījumus",
    "Expire after " : "Nederīga pēc",
    "days" : "dienas",
    "Allow users to share via link" : "Ļaut lietotājiem koplietot caur saitēm",
    "No display name set" : "Nav norādīts ekrāna vārds"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privāts",
    "Local" : "Lokāls",
    "Federated" : "Federated",
    "Verify" : "Verificēt",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Groups" : "Grupas",
    "Group list is empty" : "Grupu saraksts ir tukšš",
    "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
    "You successfully logged in using two-factor authentication (%1$s)" : "Esat veiksmīgi pieteicies, izmantojot divpakāpju autentifikācija (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pieteikšanās mēģinājums, izmantojot divpakāpju autentifikāciju neizdevās (%1$s)",
    "Wrong password" : "Nepareiza parole",
    "Saved" : "Saglabāts",
    "No user supplied" : "Nav norādīts lietotājs",
    "Authentication error" : "Autentifikācijas kļūda",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Radās kļūda, nosūtot e-pastu. Lūdzu, pārskatiet savus iestatījumus. (Kļūda: %s)",
    "Invalid user" : "Nepareizs lietotājs",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "Settings saved" : "Iestatījumi saglabāti",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "Unable to change email address" : "Nevar mainīt e-pasta adresi",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Apps" : "Lietotnes",
    "Settings" : "Iestatījumi",
    "Personal" : "Personīgs",
    "Additional settings" : "Papildu iestatījumi",
    "Sharing" : "Koplietošana",
    "Personal info" : "Personiskā informācija",
    "Email server" : "E-pasta serveris",
    "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
    "Create" : "Izveidot",
    "Change" : "Mainīt",
    "Delete" : "Dzēst",
    "Unlimited" : "Neierobežota",
    "None" : "Nav",
    "Limit to groups" : "Grupu ierobežojums",
    "Save changes" : "Saglabāt izmaiņas",
    "All" : "Visi",
    "No results" : "Nav rezultātu",
    "Update to {version}" : "Atjaunināts uz {version}",
    "Remove" : "Izņemt",
    "Disable" : "Deaktivēt",
    "Visit website" : "Apmeklējiet vietni",
    "Report a bug" : "Ziņot par kļūdu",
    "User documentation" : "Lietotāja dokumentācija",
    "Admin documentation" : "Administratora dokumentācija",
    "Developer documentation" : "Izstrādātāja dokumentācija",
    "No apps found for your version" : "Neatrada lietotnes jūsu versijai",
    "Rename" : "Pārsaukt",
    "Revoke" : "Atsaukt",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "iPhone" : "iPhone",
    "Sync client - {os}" : "Sync klients - {os}",
    "This session" : "Šajā sesijā",
    "Device" : "Ierīce",
    "Last activity" : "Pēdējās darbības",
    "App name" : "Lietotnes nosaukums",
    "Create new app password" : "Izveidot jaunu lietotnes paroli",
    "Use the credentials below to configure your app or device." : "Izmantot akreditācijas datus, lai konfigurētu savu lietotni vai ierīci.",
    "For security reasons this password will only be shown once." : "Drošības apsvērumu dēļ šī parole, tiks parādīta tikai vienreiz.",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Done" : "Pabeigts",
    "Copied!" : "Nokopēts!",
    "Copy" : "Kopēt",
    "Profile" : "Profils",
    "Enable" : "Aktivēt",
    "Server-side encryption" : "Servera šifrēšana",
    "Enable server-side encryption" : "Ieslēgt servera šifrēšanu",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrēšana vien negarantē sistēmas drošību. Skatiet dokumentāciju, lai iegūtu papildinformāciju par šifrēšanas lietotnes izmantošanu un atbalstītajiem izmantošanas veidiem.",
    "Be aware that encryption always increases the file size." : "Jāapzinās, ka šifrēšanas vienmēr palielina datnes lielumu.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Vienmēr ir ieteicams regulāri veidot dublējumkopijas datu šifrēšanas gadījumam, pārliecinieties, lai dublētu, šifrēšanas atslēgas ir kopā ar jūsu datiem.",
    "This is the final warning: Do you really want to enable encryption?" : "Šis ir pēdējais brīdinājums: vai tiešām vēlaties iespējot šifrēšanu?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nav ielādēts šifrēšanas moduļis, lūdzu, aktivizējiet šifrēšanas moduli lietotņu izvēlnē.",
    "Select default encryption module:" : "Atlasiet noklusēto šifrēšanas moduli:",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "png or jpg, max. 20 MB" : "png vai jpg, max. 20 MB",
    "Cancel" : "Atcelt",
    "Details" : "Detaļas",
    "Your email address" : "Jūsu e-pasta adrese",
    "No email address set" : "Nav norādīts e-pasts",
    "Language" : "Valoda",
    "Help translate" : "Palīdzi tulkot",
    "Your phone number" : "Jūsu tālruņa numurs",
    "Your website" : "Jūsu mājaslapa",
    "Add" : "Pievienot",
    "Display name" : "Ekrāna vārds",
    "Email" : "E-pasts",
    "Group admin for" : "Admin grupa",
    "Quota" : "Apjoms",
    "Storage location" : "Krātuves atrašanās vieta",
    "Last login" : "Pēdējā pieteikšanās",
    "Default quota" : "Apjoms pēc noklusējuma",
    "Updates" : "Atjauninājumi",
    "Add group" : "Pievienot grupu",
    "Active users" : "Aktīvie lietotāji",
    "Admins" : "Admins",
    "Send email to new user" : "Sūtīt e-pastu jaunajam lietotājam",
    "Not saved" : "Nav saglabāts",
    "Sending…" : "Sūta …",
    "Email sent" : "Vēstule nosūtīta",
    "Location" : "Vieta",
    "Profile picture" : "Profila attēls",
    "About" : "Par",
    "Full name" : "Pilns vārds",
    "Phone number" : "Tālruņa numurs",
    "Twitter" : "Twitter",
    "Website" : "Mājaslapa",
    "Hide" : "Slēpt",
    "Never" : "Nekad",
    "Administrator documentation" : "Administratora dokumentācija",
    "Documentation" : "Dokumentācija",
    "Forum" : "Forums",
    "Login" : "Autorizēties",
    "Plain" : "vienkāršs teksts",
    "NT LAN Manager" : "NT LAN Pārvaldnieks",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Atvērt dokumentāciju",
    "Send mode" : "Sūtīšanas metode",
    "Encryption" : "Šifrēšana",
    "From address" : "No adreses",
    "Authentication method" : "Autentifikācijas metode",
    "Authentication required" : "Nepieciešama autentifikācija",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Credentials" : "Akreditācijas dati",
    "SMTP Username" : "SMTP lietotājvārds",
    "SMTP Password" : "SMTP parole",
    "Save" : "Saglabāt",
    "Send email" : "Sūtīt e-pastu",
    "All checks passed." : "Visas pārbaudes veiksmīgas.",
    "Version" : "Versija",
    "Allow apps to use the Share API" : "Ļaut programmām izmantot koplietošanas API",
    "Enforce expiration date" : "Uzspiest beigu termiņu",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Enforce password protection" : "Ieviest paroles aizsardzību",
    "Set default expiration date" : "Iestatīt noklusējuma beigu datumu",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Allow sharing with groups" : "Atļaut koplietošanu ar grupām",
    "Restrict users to only share with users in their groups" : "Ierobežot lietotājiem koplietot tikai ar lietotājiem savās grupās",
    "Exclude groups from sharing" : "Izslēgt grupas no koplietošanas",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Izstrādātās {communityopen}Nextcloud kopiena {linkclose},  {githubopen} avota kods {linkclose} licencēts saskaņā ar {licenseopen}AGPL{linkclose}.",
    "Migration in progress. Please wait until the migration is finished" : "Notiek migrācija. Lūdzu, pagaidiet, līdz migrēšana ir pabeigta",
    "Migration started …" : "Uzsākta migrācija...",
    "Select a profile picture" : "Izvēlieties profila attēlu",
    "Couldn't remove app." : "Nebija iespējams noņemt lietotni.",
    "Couldn't update app." : "Nevarēja atjaunināt lietotni.",
    "You need to set your user email before being able to send test emails." : "Nepieciešams norādīt sava lietotāja e-pasta adresi, lai nosūtīta testa e-pastus.",
    "All languages" : "Visas valodas",
    "Everyone" : "Visi",
    "Test email settings" : "Izmēģināt e-pasta iestatījumus",
    "Please read carefully before activating server-side encryption: " : "Lūdzu, izlasiet uzmanīgi pirms aktivējiet servera šifrēšanu:",
    "Enable encryption" : "Ieslēgt šifrēšanu",
    "Start migration" : "Sākt migrāciju",
    "Recommended" : "Rekomendēts",
    "days" : "dienas",
    "Upload new" : "Ielādēt jaunu",
    "Select from Files" : "Izvēlēties no Datnes",
    "Remove image" : "Novākt attēlu",
    "Choose as profile picture" : "Izvēlēties kā profila attēlu",
    "No display name set" : "Nav norādīts ekrāna vārds",
    "Address" : "Adrese",
    "Your postal address" : "Jūsu pasta adrese",
    "Avatar" : "Profila attēls"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
